import type { Browser, Cache, CacheDetails, Content, Cookie, Creator, Entry, Har, Header, Log, Page, PageTiming, PostData, QueryString, Request, Response, Timings } from "har-format";
export interface DataValidationCxt<T extends string | number = string | number> {
    instancePath: string;
    parentData: {
        [K in T]: any;
    };
    parentDataProperty: T;
    rootData: Record<string, any> | any[];
}
interface ErrorObject<K extends string = string, P = Record<string, any>, S = unknown> {
    keyword: K;
    instancePath: string;
    schemaPath: string;
    params: P;
    propertyName?: string;
    message?: string;
    schema?: S;
    data?: unknown;
}
export declare class HARError extends Error {
    name: string;
    message: string;
    errors: ErrorObject[];
    constructor(errors: ErrorObject[]);
}
export declare type TypeValidatorName = keyof TypeMappings;
interface TypeMappings {
    request: Request;
    afterRequest: CacheDetails;
    beforeRequest: CacheDetails;
    browser: Browser;
    cache: Cache;
    content: Content;
    cookie: Cookie;
    creator: Creator;
    entry: Entry;
    har: Har;
    header: Header;
    log: Log;
    page: Page;
    pageTimings: PageTiming;
    postData: PostData;
    query: QueryString;
    response: Response;
    timings: Timings;
}
export declare const validate: <T extends keyof TypeMappings>(schema: T, obj: unknown) => obj is TypeMappings[T];
export declare const validateRequest: (request: unknown) => request is Request;
export declare const validateResponse: (response: unknown) => response is Response;
export declare const validateHar: (har: unknown) => har is Request;
export default validateRequest;
